# Copyright (c) 2003-2004 Chalmers University of Technology
# Authors: Jean-Marc Orliaguet <jmo@ita.chalmers.se>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License version 2 as published
# by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# YoU should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
# 02111-1307, USA.
#

__author__ = "Jean-Marc Orliaguet <jmo@ita.chalmers.se>"

"""
  ImageBox Templet
"""

from Globals import InitializeClass
from AccessControl import ClassSecurityInfo
from Products.CMFCore.CMFCorePermissions import View
from OFS.Image import Image

from BaseTemplet import BaseTemplet
from ThemeFolder import ThemeFolder
from CPSSkinsPermissions import ManageThemes

def addImageBox(dispatcher, id, REQUEST=None, **kw):
    """Add an Image Box Templet."""

    ob = ImageBox(id, **kw)
    dispatcher._setObject(id, ob)
    if REQUEST is not None:
        url = dispatcher.DestinationURL()
        REQUEST.RESPONSE.redirect('%s/manage_main' % url)

factory_type_information = (
    {'id': 'Image Box Templet',
     'title': 'Image box',
     'description': ('_imagebox_templet_description_'),
     'meta_type': 'Image Box Templet',
     'icon': 'imagebox_templet.gif',
     'product': 'CPSSkins',
     'factory': 'addImageBox',
     'immediate_view': 'cpsskins_edit_form',
     'filter_content_types': 0,
     'global_allow': 0,
     'actions': BaseTemplet._actions + (),
    },
)


class ImageBox(ThemeFolder, Image, BaseTemplet):
    """
    Image Box Templet.
    """
    meta_type = 'Image Box Templet'
    portal_type = 'Image Box Templet'

    render_action = 'cpsskins_imagebox'

    security = ClassSecurityInfo()

    _properties = BaseTemplet._properties + (
        {'id': 'i18n', 
         'type': 'boolean', 
         'mode': 'w', 
         'label': 'Translate the image',
         'default': 0, 
        },
        {'id': 'caption', 
         'type': 'string', 
         'mode': 'w', 
         'label': 'Image caption', 
         'category': 'general',
        },
        {'id': 'link', 
         'type': 'string', 
         'mode': 'w', 
         'label': 'Link (http://, mailto: ...)', 
         'category': 'general',
        },
        {'id': 'use_internal_link', 
         'type': 'boolean', 
         'mode': 'w', 
         'label': 'Use internal link?', 
         'category': 'general',
         'default': 0,
        },
        {'id': 'internal_link', 
         'type': 'selection', 
         'mode': 'w', 
         'label': 'Internal link', 
         'select_variable': 'cpsskins_listPaths', 
         'visible': 'ifUseInternalLink',
         'category' : 'general',
        },
        )

    def __init__(self, id, title,
                       i18n = 0,
                       caption = '',
                       link = '',
                       internal_link = '',
                       use_internal_link = 0,
                       file = '',
                       content_type = '',
                       precondition = '',
                       **kw) :
        apply(Image.__init__, (self, id, title, file, content_type, precondition))
        apply(BaseTemplet.__init__, (self, id), kw)
        self.i18n = i18n
        self.caption = caption
        self.link = link
        self.internal_link = internal_link
        self.use_internal_link = use_internal_link
      

    security.declarePublic('isCacheable')
    def isCacheable(self):
        """ Returns true if the Templet can be cached in RAM """

        return 1

    security.declarePublic('isPortalTemplet')
    def isPortalTemplet(self):
        """ is portal templet """
           
        return 1

    security.declarePublic('isImageBox')
    def isImageBox(self):
        """ Templet is an image box """
           
        return 1

    security.declarePublic('getCacheIndex')
    def getCacheIndex(self, REQUEST=None):
        """ returns the RAM cache index as a tuple (var1, var2, ...) """
       
        index = ()
        if REQUEST is None:
            REQUEST = self.REQUEST

        if getattr(self, 'i18n', 0):
            index += (REQUEST.get('cpsskins_language', 'en'), )
        return index

    security.declarePublic('getI18nProperties')
    def getI18nProperties(self):
        """ Returns the list of i18n properties """

        return ['i18n',]

    security.declareProtected(ManageThemes, 'upload_image')
    def upload_image(self, REQUEST=None, **kw):
        """
        Uploads the image
        If the i18n attribute is set the image will be uploaded 
        inside this folder and be called 'i18n_image_xx' where 'xx'
        is the 2-letter language code.
        """

        if REQUEST is not None:
            kw.update(REQUEST.form)
        file = kw.get('file', None)
        if file is None:
            return 
        if file.filename == '':
            return

        if not getattr(self, 'i18n', 0):
            self.manage_upload(file)
        else:
            lang_id = self.getDefaultLang()
            if lang_id is not None:
                img_id = 'i18n_image_%s' % lang_id
                i18n_images = self.getI18nImages()
                if img_id in i18n_images.keys():
                    self.manage_delObjects(img_id)
                cmfdefault = self.manage_addProduct['CMFDefault']
                cmfdefault.manage_addContent(id=img_id, type='Portal Image')
                img = getattr(self.aq_explicit, img_id, None)
                img.manage_upload(file)

        self.invalidateRAMCache()

        if REQUEST is not None:
            url = REQUEST['HTTP_REFERER'] 
            REQUEST.RESPONSE.redirect(url)


    security.declarePublic('getI18nImages')
    def getI18nImages(self):
        """ returns a dictionary of internalized images 
            {id: <Image>, ...}
        """

        images = {}
        for obj in self.objectValues('Portal Image'):
            obj_id = obj.getId()
            if obj_id.startswith('i18n_image_'):
                images[obj_id] = obj
        return images


    security.declareProtected(ManageThemes, 'edit')
    def edit(self, **kw):
        """
        Default edit method, changes the properties.
        """
        self.manage_changeProperties(**kw)
        self.invalidateRAMCache()


    security.declarePublic('ifUseInternalLink')
    def ifUseInternalLink(self):
        """
        True if the 'use internal link' option is set
        """

        return getattr(self, 'use_internal_link', 0)

InitializeClass(ImageBox)
